@@ -11,6 +11,7 @@ namespace KIdentityManagementCore
 class IdentityActivitiesAbstract;
 class KIDENTITYMANAGEMENTCORE_EXPORT IdentityTreeSortProxyModel : public QSortFilterProxyModel
 {
+    Q_OBJECT
 public:
     explicit IdentityTreeSortProxyModel(QObject *parent);
     ~IdentityTreeSortProxyModel() override;
@@ -19,7 +20,7 @@ public:
     void setIdentityActivitiesAbstract(IdentityActivitiesAbstract *newIdentityActivitiesAbstract);
 
 protected:
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    [[nodiscard]] bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
     IdentityActivitiesAbstract *mIdentityActivitiesAbstract = nullptr;
